@@ -36,8 +36,10 @@ def requires_data(func):
 
 
 class ImageClient(VizClient):
+
     display_data = CallbackProperty(None)
     display_attribute = CallbackProperty(None)
+    display_aspect = CallbackProperty('equal')
 
     def __init__(self, data, artist_container=None):
 
@@ -327,14 +329,20 @@ class ImageClient(VizClient):
 
         self._view = view
         for a in list(self.artists):
-            if (not isinstance(a, ScatterLayerBase)) and \
-                    a.layer.data is not self.display_data:
+            if (not isinstance(a, ScatterLayerBase) and
+                    a.layer.data is not self.display_data):
                 self.artists.remove(a)
             else:
-                a.update(view, transpose)
+                if isinstance(a, ImageLayerArtist):
+                    a.update(view, transpose, aspect=self.display_aspect)
+                else:
+                    a.update(view, transpose)
         for a in self.artists[self.display_data]:
             meth = a.update if not force else a.force_update
-            meth(view, transpose=transpose)
+            if isinstance(a, ImageLayerArtist):
+                meth(view, transpose=transpose, aspect=self.display_aspect)
+            else:
+                meth(view, transpose=transpose)
 
     def _update_subset_single(self, s, redraw=False, force=False):
         """
@@ -361,7 +369,10 @@ class ImageClient(VizClient):
         transpose = self.slice.index('x') < self.slice.index('y')
         for a in self.artists[s]:
             meth = a.update if not force else a.force_update
-            meth(view, transpose)
+            if isinstance(a, SubsetImageLayerArtist):
+                meth(view, transpose=transpose, aspect=self.display_aspect)
+            else:
+                meth(view, transpose=transpose)
 
         if redraw:
             self._redraw()
@@ -401,10 +412,15 @@ class ImageClient(VizClient):
                 self.delete_layer(subset)
 
         if layer is self.display_data:
-            if len(self.artists) > 0:
-                self.display_data = self.artists.layers[0].data
+            for layer in self.artists:
+                if isinstance(layer, ImageLayerArtist):
+                    self.display_data = layer.data
+                    break
             else:
+                for artist in self.artists:
+                    self.delete_layer(artist.layer)
                 self.display_data = None
+                self.display_attribute = None
 
         self._redraw()
 
@@ -464,6 +480,10 @@ class ImageClient(VizClient):
         self._redraw()
         return result
 
+    def _update_aspect(self):
+        self._update_data_plot(relim=True)
+        self._redraw()
+
     def add_layer(self, layer):
         if layer in self.artists:
             return self.artists[layer][0]
@@ -736,11 +756,14 @@ class MplImageClient(ImageClient):
         vw = _view_window(self._axes)
         if vw != self._view_window:
             logging.getLogger(__name__).debug("updating")
-            self._update_data_plot()
-            self._update_subset_plots()
-            self._redraw()
+            self._update_and_redraw()
             self._view_window = vw
 
+    def _update_and_redraw(self):
+        self._update_data_plot()
+        self._update_subset_plots()
+        self._redraw()
+
     @requires_data
     def _update_axis_labels(self):
         labels = _axis_labels(self.display_data, self.slice)
