@@ -15,7 +15,10 @@ __all__ = ['Registry', 'SettingRegistry', 'ExporterRegistry',
            'SingleSubsetLayerActionRegistry', 'ProfileFitterRegistry',
            'qt_client', 'data_factory', 'link_function', 'link_helper',
            'colormaps', 'exporters', 'settings', 'fit_plugin',
-           'auto_refresh', 'importer']
+           'auto_refresh', 'importer', 'DictRegistry']
+
+
+CFG_DIR = os.path.join(os.path.expanduser('~'), '.glue')
 
 
 class Registry(object):
@@ -90,7 +93,35 @@ class Registry(object):
         return arg
 
 
-class SettingRegistry(Registry):
+class DictRegistry(Registry):
+    """
+    Base class for registries that are based on dictionaries instead of lists
+    of objects.
+    """
+
+    def __init__(self):
+        self._members = {}
+        self._lazy_members = []
+        self._loaded = False
+
+    @property
+    def members(self):
+        self._load_lazy_members()
+        if not self._loaded:
+            defaults = self.default_members()
+            for key in defaults:
+                if key in self._members:
+                    self._members[key].extend(defaults[key])
+                else:
+                    self._members[key] = defaults[key]
+            self._loaded = True
+        return self._members
+
+    def default_members(self):
+        return {}
+
+
+class SettingRegistry(DictRegistry):
 
     """Stores key/value settings that code can use to customize Glue
 
@@ -102,12 +133,34 @@ class SettingRegistry(Registry):
                    returns the (possibly sanitized) setting value.
     """
 
-    def add(self, key, value, validator=str):
-        self.members.append((key, value, validator))
+    def __init__(self):
+        super(SettingRegistry, self).__init__()
+        self._validators = {}
 
-    def default_members(self):
-        import glue.plugins  # plugins will populate this registry
-        return []
+    def add(self, key, value, validator=str):
+        self._members[key] = validator(value)
+        self._validators[key] = validator
+
+    def __getattr__(self, attr):
+        if attr.startswith('_'):
+            raise AttributeError("No such setting: {0}".format(attr))
+        else:
+            try:
+                return self._members[attr]
+            except KeyError:
+                raise AttributeError("No such setting: {0}".format(attr))
+
+    def __setattr__(self, attr, value):
+        if attr.startswith('_'):
+            object.__setattr__(self, attr, value)
+        elif attr in self._members:
+            self._members[attr] = self._validators[attr](value)
+        else:
+            raise AttributeError("No such setting: {0}".format(attr))
+
+    def __iter__(self):
+        for key in self._members:
+            yield key, self._members[key], self._validators[key]
 
 
 class DataImportRegistry(Registry):
@@ -119,9 +172,6 @@ class DataImportRegistry(Registry):
     arguments and return a list of :class:`~glue.core.data.Data` objects.
     """
 
-    def default_members(self):
-        return []
-
     def add(self, label, importer):
         """
         Add a new importer
@@ -149,9 +199,6 @@ class MenubarPluginRegistry(Registry):
     are a reference to the session and to the data collection respectively.
     """
 
-    def default_members(self):
-        return []
-
     def add(self, label, function):
         """
         Add a new menubar plugin
@@ -189,10 +236,6 @@ class ExporterRegistry(Registry):
       'label': exporter doesn't write to disk, but needs a label
     """
 
-    def default_members(self):
-        import glue.plugins  # discover plugins
-        return []
-
     def add(self, label, exporter, checker, outmode='file'):
         """
         Add a new exporter
@@ -247,40 +290,51 @@ class DataFactoryRegistry(Registry):
     """Stores data factories. Data factories take filenames as input,
     and return :class:`~glue.core.data.Data` instances
 
-    The members property returns a list of (function, label, identifier)
-    namedtuples:
+    The members property returns a list of (function, label, identifier,
+    priority) namedtuples:
 
     - Function is the factory that creates the data object
     - label is a short human-readable description of the factory
     - identifier is a function that takes ``(filename, **kwargs)`` as input
       and returns True if the factory can open the file
+    - priority is a numerical value that indicates how confident the data
+      factory is that it should read the data, relative to other data
+      factories. For example, a highly specialized FITS reader for specific
+      FITS file types can be given a higher priority than the generic FITS
+      reader in order to take precedence over it.
 
     New data factories can be registered via::
 
-        @data_factory('label_name', identifier, default='txt')
+        @data_factory('label_name', identifier=identifier, priority=10)
         def new_factory(file_name):
             ...
 
-    This has the additional side-effect of associating
-    this this factory with filenames ending in ``txt`` by default
+    If not specified, the priority defaults to 0.
     """
-    item = namedtuple('DataFactory', 'function label identifier')
 
-    def default_members(self):
-        from .core.data_factories import __factories__
-        return [self.item(f, f.label, f.identifier) for f in __factories__]
+    item = namedtuple('DataFactory', 'function label identifier priority deprecated')
+
+    def __call__(self, label, identifier=None, priority=None, default='', deprecated=False):
 
-    def __call__(self, label, identifier=None, default=''):
-        from .core.data_factories import set_default_factory
         if identifier is None:
             identifier = lambda *a, **k: False
 
+        if priority is None:
+            if deprecated:
+                priority = -1000
+            else:
+                priority = 0
+
         def adder(func):
-            set_default_factory(default, func)
-            self.add(self.item(func, label, identifier))
+            self.add(self.item(func, label, identifier, priority, deprecated))
             return func
+
         return adder
 
+    def __iter__(self):
+        for member in sorted(self.members, key=lambda x: (-x.priority, x.label)):
+            yield member
+
 
 class QtClientRegistry(Registry):
 
@@ -306,25 +360,7 @@ class QtClientRegistry(Registry):
             return []
 
 
-class QtToolRegistry(Registry):
-
-    def __init__(self):
-        self._members = {}
-        self._lazy_members = []
-        self._loaded = False
-
-    @property
-    def members(self):
-        self._load_lazy_members()
-        if not self._loaded:
-            defaults = self.default_members()
-            for key in defaults:
-                if key in self._members:
-                    self._members[key].extend(defaults[key])
-                else:
-                    self._members[key] = defaults[key]
-            self._loaded = True
-        return self._members
+class QtToolRegistry(DictRegistry):
 
     def default_members(self):
         defaults = {}
@@ -394,9 +430,6 @@ class SingleSubsetLayerActionRegistry(Registry):
     """
     item = namedtuple('SingleSubsetLayerAction', 'label tooltip callback icon')
 
-    def default_members(self):
-        return []
-
     def __call__(self, label, callback, tooltip=None, icon=None):
         self.add(self.item(label, callback, tooltip, icon))
 
@@ -480,7 +513,6 @@ menubar_plugin = MenubarPluginRegistry()
 auto_refresh = BooleanSetting(False)
 enable_contracts = BooleanSetting(False)
 
-
 def load_configuration(search_path=None):
     ''' Find and import a config.py file
 
@@ -520,8 +552,32 @@ def _default_search_order():
        * HOME/.glue/config.py
        * Glue's own default config
     """
+
+    from . import config
+
     search_order = [os.path.join(os.getcwd(), 'config.py')]
     if 'GLUERC' in os.environ:
         search_order.append(os.environ['GLUERC'])
-    search_order.append(os.path.expanduser('~/.glue/config.py'))
+    search_order.append(os.path.join(config.CFG_DIR, 'config.py'))
     return search_order[::-1]
+
+
+###### Now define global settings ######
+
+GRAY = '#373737'
+BLUE = "#1F78B4"
+GREEN = "#33A02C"
+RED = "#E31A1C"
+ORANGE = "#FF7F00"
+PURPLE = "#6A3D9A"
+YELLOW = "#FFFF99"
+BROWN = "#8C510A"
+PINK = "#FB9A99"
+LIGHT_BLUE = "#A6CEE3"
+LIGHT_GREEN = "#B2DF8A"
+LIGHT_RED = "#FB9A99"
+LIGHT_ORANGE = "#FDBF6F"
+LIGHT_PURPLE = "#CAB2D6"
+
+settings.add('SUBSET_COLORS', [RED, GREEN, BLUE, BROWN, ORANGE, PURPLE, PINK], validator=list)
+settings.add('DATA_COLOR', GRAY)
