@@ -1,9 +1,13 @@
 from __future__ import absolute_import, division, print_function
 
 from .helpers import *
-from .gridded import *
+from .fits import *
+from .hdf5 import *
+from .astropy_table import *
 from .pandas import *
 from .excel import *
 from .image import *
 from .tables import *
 from .dendrogram import *
+
+# from .deprecated import *
