@@ -4,7 +4,10 @@ import numpy as np
 
 from ..data import Data, Component, CategoricalComponent
 
-from .helpers import has_extension, __factories__
+from .helpers import has_extension
+
+from ...external import six
+from ...config import data_factory
 
 __all__ = ['pandas_read_table']
 
@@ -29,6 +32,12 @@ def panda_process(indf):
         else:
             c = Component(column.values)
 
+        # convert header to string - in some cases if the first row contains
+        # numbers, these are cast to numerical types, so we want to change that
+        # here.
+        if not isinstance(name, six.string_types):
+            name = str(name)
+
         # strip off leading #
         name = name.strip()
         if name.startswith('#'):
@@ -39,6 +48,7 @@ def panda_process(indf):
     return result
 
 
+@data_factory(label="Pandas Table", identifier=has_extension('csv csv txt tsv tbl dat'))
 def pandas_read_table(path, **kwargs):
     """ A factory for reading tabular data using pandas
     :param path: path/to/file
@@ -48,7 +58,7 @@ def pandas_read_table(path, **kwargs):
     import pandas as pd
     try:
         from pandas.parser import CParserError
-    except ImportError:
+    except ImportError:  # pragma: no cover
         from pandas._parser import CParserError
 
     # iterate over common delimiters to search for best option
@@ -79,6 +89,3 @@ def pandas_read_table(path, **kwargs):
         return panda_process(fallback)
     raise IOError("Could not parse %s using pandas" % path)
 
-pandas_read_table.label = "Pandas Table"
-pandas_read_table.identifier = has_extension('csv csv txt tsv tbl dat')
-__factories__.append(pandas_read_table)
