@@ -30,7 +30,6 @@ from ...config import fit_plugin
 from ...external.six.moves import range as xrange
 from ...qt.widgets.glue_mdi_area import GlueMdiSubWindow
 from ...qt.decorators import messagebox_on_error
-from ...utils import drop_axis
 
 
 def setup():
@@ -271,7 +270,6 @@ class NavContext(SpectrumContext):
 
 
 class CollapseContext(SpectrumContext):
-
     """
     Mode to collapse a section of a cube into a 2D image.
 
@@ -356,7 +354,8 @@ class CollapseContext(SpectrumContext):
         pth : str
            Path to write to
         """
-        from astropy.io import fits
+
+        from ...external.astro import fits
 
         data = self.client.display_data
         if data is None:
@@ -368,12 +367,14 @@ class CollapseContext(SpectrumContext):
         wcs = getattr(data.coords, 'wcs', None)
         if wcs:
             try:
-                wcs = drop_axis(wcs, data.ndim - 1 - self.main.profile_axis)
+                wcs.dropaxis(data.ndim - 1 - self.main.profile_axis)
                 header = wcs.to_header(True)
             except Exception as e:
                 msg = "Could not extract 2D wcs for this data: %s" % e
                 logging.getLogger(__name__).warn(msg)
                 header = fits.Header()
+        else:
+            header = fits.Header()
 
         lo, hi = self.grip.range
         history = ('Created by Glue. %s projection over channels %i-%i of axis %i. Slice=%s' %
@@ -754,7 +755,8 @@ class SpectrumTool(object):
     def _setup_mouse_mode(self):
         # This will be added to the ImageWidget's toolbar
         mode = SpectrumExtractorMode(self.image_widget.client.axes,
-                                     release_callback=self._update_profile)
+                                     release_callback=self._update_profile,
+                                     move_callback=self._move_profile)
         return mode
 
     def _setup_toolbar(self):
@@ -837,6 +839,10 @@ class SpectrumTool(object):
         roi = self.mouse_mode.roi()
         return self._update_from_roi(roi)
 
+    def _move_profile(self, *args):
+        if self.mouse_mode._roi_tool._scrubbing:
+            self._update_profile(args)
+
     def _set_profile(self, x, y):
         data = self.data
 
@@ -846,7 +852,7 @@ class SpectrumTool(object):
 
         xlim = self.axes.get_xlim()
         self.profile.set_xlabel(xlabel)
-        self.profile.set_profile(x, y, c='k')
+        self.profile.set_profile(x, y, color='k')
 
         # relim x range if requested
         if self._relim_requested:
@@ -882,4 +888,4 @@ class SpectrumTool(object):
 
     def _display_data_hook(self, data):
         if data is not None:
-            self.mouse_mode.enabled = data.ndim > 2
\ No newline at end of file
+            self.mouse_mode.enabled = data.ndim > 2
