@@ -4,6 +4,7 @@ from __future__ import absolute_import, division, print_function
 
 import os
 import sys
+import warnings
 import webbrowser
 
 from ..external.qt.QtGui import (QKeySequence, QMainWindow, QGridLayout,
@@ -33,9 +34,10 @@ from .widgets.data_viewer import DataViewer
 from .widgets.settings_editor import SettingsEditor
 from .widgets.mpl_widget import defer_draw
 from .feedback import submit_bug_report
+from .plugin_manager import QtPluginManager
 
 __all__ = ['GlueApplication']
-DOCS_URL = 'http://www.glue-viz.org'
+DOCS_URL = 'http://www.glueviz.org'
 
 
 def _fix_ipython_pylab():
@@ -512,7 +514,9 @@ class GlueApplication(Application, QMainWindow):
         mbar.addMenu(menu)
 
         menu = QMenu(mbar)
-        menu.setTitle("&Tools")
+        menu.setTitle("&Plugins")
+        menu.addAction(self._actions['plugin_manager'])
+        menu.addSeparator()
 
         if 'plugins' in self._actions:
             for plugin in self._actions['plugins']:
@@ -653,6 +657,11 @@ class GlueApplication(Application, QMainWindow):
             acts.append(a)
         self._actions['plugins'] = acts
 
+        a = act('&Plugin Manager', self,
+                tip='Open plugin manager')
+        a.triggered.connect(nonpartial(self.plugin_manager))
+        self._actions['plugin_manager'] = a
+
     def choose_new_data_viewer(self, data=None):
         """ Create a new visualization window in the current tab
         """
@@ -686,8 +695,15 @@ class GlueApplication(Application, QMainWindow):
         # include file filter twice, so it shows up in Dialog
         outfile, file_filter = QFileDialog.getSaveFileName(self,
                                                            filter="Glue Session (*.glu);; Glue Session including data (*.glu)")
+
+        # This indicates that the user cancelled
         if not outfile:
             return
+
+        # Add extension if not specified
+        if not '.' in outfile:
+            outfile += '.glu'
+
         self.save_session(outfile, include_data="including data" in file_filter)
 
     @messagebox_on_error("Failed to export session")
@@ -716,7 +732,7 @@ class GlueApplication(Application, QMainWindow):
         if not file_name:
             return
 
-        ga = self.restore(file_name)
+        ga = self.restore_session(file_name)
         self.close()
         return ga
 
@@ -742,22 +758,23 @@ class GlueApplication(Application, QMainWindow):
         return ga
 
     @staticmethod
-    def restore(path, show=True):
-        """Reload a previously-saved session
-
-        :param path: Path to the file to load
-        :type path: str
-        :param show: If True (the default), immediately show the widget
-        :type show: bool
-
-        :returns: A new :class:`GlueApplication`
+    def restore_session(path, show=True):
         """
-        from ..core.state import GlueUnSerializer
+        Reload a previously-saved session
 
-        with open(path) as infile:
-            state = GlueUnSerializer.load(infile)
+        Parameters
+        ----------
+        path : str
+            Path to the file to load
+        show : bool, optional
+            If True (the default), immediately show the widget
 
-        ga = state.object('__main__')
+        Returns
+        -------
+        app : :class:`GlueApplication`
+            The loaded application
+        """
+        ga = Application.restore_session(path)
         if show:
             ga.show()
         return ga
@@ -819,10 +836,12 @@ class GlueApplication(Application, QMainWindow):
     def _toggle_terminal(self):
         if self._terminal.isVisible():
             self._hide_terminal()
-            assert not self._terminal.isVisible()
+            if self._terminal.isVisible():
+                warnings.warn("An unexpected error occurred while trying to hide the terminal")
         else:
             self._show_terminal()
-            assert self._terminal.isVisible()
+            if not self._terminal.isVisible():
+                warnings.warn("An unexpected error occurred while trying to show the terminal")
 
     def _hide_terminal(self):
         self._terminal.hide()
@@ -896,6 +915,11 @@ class GlueApplication(Application, QMainWindow):
         qmb.resize(400, qmb.size().height())
         qmb.exec_()
 
+    def plugin_manager(self):
+        from ..main import _installed_plugins
+        pm = QtPluginManager(installed=_installed_plugins)
+        pm.ui.exec_()
+
     def _update_undo_redo_enabled(self):
         undo, redo = self._cmds.can_undo_redo()
         self._actions['undo'].setEnabled(undo)
