@@ -115,7 +115,7 @@ class GlueDataDialog(object):
         self._fd = QtGui.QFileDialog(parent)
         from glue.config import data_factory
         self.filters = [(f, self._filter(f))
-                        for f in data_factory.members]
+                        for f in data_factory.members if not f.deprecated]
         self.setNameFilter()
         self._fd.setFileMode(QtGui.QFileDialog.ExistingFiles)
         try:
@@ -980,7 +980,7 @@ def update_combobox(combo, labeldata):
     """
     combo.blockSignals(True)
     idx = combo.currentIndex()
-    if idx > 0:
+    if idx >= 0:
         current = combo.itemData(idx)
     else:
         current = None
@@ -994,6 +994,12 @@ def update_combobox(combo, labeldata):
     combo.blockSignals(False)
     combo.setCurrentIndex(index)
 
+    # We need to force emit this, otherwise if the index happens to be the
+    # same as before, even if the data is different, callbacks won't be
+    # called.
+    if idx == index or idx == -1:
+        combo.currentIndexChanged.emit(index)
+
     return combo
 
 
