@@ -48,6 +48,8 @@ class ImageWidgetBase(DataViewer):
                                      'Current attribute')
     data = CurrentComboProperty('ui.displayDataCombo',
                                 'Current data')
+    aspect_ratio = CurrentComboProperty('ui.aspectCombo',
+                                        'Aspect ratio for image')
     rgb_mode = ButtonProperty('ui.rgb',
                               'RGB Mode?')
     rgb_viz = Pointer('ui.rgb_options.rgb_visible')
@@ -74,6 +76,9 @@ class ImageWidgetBase(DataViewer):
         self.ui.slice_layout.addWidget(self.ui.slice)
         self._tweak_geometry()
 
+        self.ui.aspectCombo.addItem("Square Pixels", userData='equal')
+        self.ui.aspectCombo.addItem("Automatic", userData='auto')
+
     def make_client(self):
         """ Instantiate and return an ImageClient subclass """
         raise NotImplementedError()
@@ -133,6 +138,8 @@ class ImageWidgetBase(DataViewer):
             r = self.client.add_layer(data)
             if r is not None and self.client.display_data is not None:
                 self.add_data_to_combo(data)
+                if self.client.can_image_data(data):
+                    self.client.display_data = data
                 self.set_attribute_combo(self.client.display_data)
 
         return r is not None
@@ -213,12 +220,34 @@ class ImageWidgetBase(DataViewer):
         add_callback(self.client, 'display_data', self.ui.slice.set_data)
 
         # sync window title to data/attribute
-        add_callback(self.client, 'display_data', nonpartial(self.update_window_title))
-        add_callback(self.client, 'display_attribute', nonpartial(self.update_window_title))
+        add_callback(self.client, 'display_data', nonpartial(self._display_data_changed))
+        add_callback(self.client, 'display_attribute', nonpartial(self._display_attribute_changed))
+        add_callback(self.client, 'display_aspect', nonpartial(self.client._update_aspect))
 
         # sync data/attribute combos with client properties
         connect_current_combo(self.client, 'display_data', self.ui.displayDataCombo)
         connect_current_combo(self.client, 'display_attribute', self.ui.attributeComboBox)
+        connect_current_combo(self.client, 'display_aspect', self.ui.aspectCombo)
+
+    def _display_data_changed(self):
+
+        if self.client.display_data is None:
+            self.ui.attributeComboBox.clear()
+            return
+
+        with self.client.artists.ignore_empty():
+            self.set_attribute_combo(self.client.display_data)
+        self.client.add_layer(self.client.display_data)
+        self.client._update_and_redraw()
+        self.update_window_title()
+
+    def _display_attribute_changed(self):
+
+        if self.client.display_attribute is None:
+            return
+
+        self.client._update_and_redraw()
+        self.update_window_title()
 
     @defer_draw
     def _update_rgb_console(self, is_monochrome):
@@ -240,7 +269,7 @@ class ImageWidgetBase(DataViewer):
         self.client.register_to_hub(hub)
 
         dc_filt = lambda x: x.sender is self.client._data
-        layer_present_filter = lambda x: x.data in self.client.artists
+        display_data_filter = lambda x: x.data is self.client.display_data
 
         hub.subscribe(self,
                       core.message.DataCollectionAddMessage,
@@ -257,7 +286,7 @@ class ImageWidgetBase(DataViewer):
         hub.subscribe(self,
                       core.message.ComponentsChangedMessage,
                       handler=lambda x: self.set_attribute_combo(x.data),
-                      filter=layer_present_filter)
+                      filter=display_data_filter)
 
     def unregister(self, hub):
         super(ImageWidgetBase, self).unregister(hub)
@@ -436,6 +465,7 @@ class ImageWidget(ImageWidgetBase):
     def _connect(self):
         super(ImageWidget, self)._connect()
         self.ui.rgb_options.current_changed.connect(lambda: self._toolbars[0].set_mode(self._contrast))
+        self.central_widget.canvas.resize_end.connect(self.client.check_update)
 
 
 class ColormapAction(QAction):
