@@ -38,37 +38,8 @@ def test_add_link_default():
     assert val in link_function
 
 
-def test_data_facotry_defaults():
-    from ..core.data_factories import __factories__
-    assert len(__factories__) > 0
-
-    for f in __factories__:
-        assert f in (ff[0] for ff in data_factory.members)
-
-
 def test_add_data_factory():
     @data_factory('XYZ file', "*txt")
     def foo(x):
         pass
-    assert (foo, 'XYZ file', '*txt') in data_factory
-
-
-def test_data_factory_default():
-    from ..core.data_factories import get_default_factory
-
-    @data_factory("XYZ file", '*xyz', 'xyz abc')
-    def foo(x):
-        pass
-    assert get_default_factory('xyz') is foo
-    assert get_default_factory('abc') is foo
-
-    @data_factory('ABC file', '*abc', 'abc')
-    def bar(x):
-        pass
-
-    assert get_default_factory('xyz') is foo
-    assert get_default_factory('abc') is bar
-
-    @data_factory('', '', '')
-    def baz(x):
-        pass
+    assert (foo, 'XYZ file', '*txt', 0, False) in data_factory
